@@ -2,15 +2,17 @@ mod auxv;
 mod types;
 mod wait;
 
+pub(crate) mod cpu_set;
+
 #[cfg(target_vendor = "mustang")]
 pub(crate) use auxv::init;
 pub(crate) use auxv::{exe_phdrs, linux_execfn, linux_hwcap, page_size};
 pub(super) use auxv::{exe_phdrs_slice, sysinfo_ehdr};
+pub(crate) use types::{raw_cpu_set_new, RawCpuSet, CPU_SETSIZE};
 pub use types::{
     MembarrierCommand, RawCpuid, RawGid, RawPid, RawUid, RawUname, Resource, EXIT_FAILURE,
     EXIT_SIGNALED_SIGABRT, EXIT_SUCCESS,
 };
-pub(crate) use types::{RawCpuSet, CPU_SETSIZE};
 pub(crate) use wait::{
     WCONTINUED, WEXITSTATUS, WIFCONTINUED, WIFEXITED, WIFSIGNALED, WIFSTOPPED, WNOHANG, WSTOPSIG,
     WTERMSIG, WUNTRACED,
