@@ -45,14 +45,11 @@
 
 #![deny(missing_docs)]
 #![cfg_attr(linux_raw, deny(unsafe_code))]
-#![cfg_attr(linux_raw_inline_asm, feature(asm))]
+#![cfg_attr(asm, feature(asm))]
 #![cfg_attr(any(rustc_attrs, feature = "rustc-dep-of-std"), feature(rustc_attrs))]
 #![cfg_attr(doc_cfg, feature(doc_cfg))]
 #![cfg_attr(target_os = "wasi", feature(wasi_ext))]
-#![cfg_attr(
-    all(linux_raw_inline_asm, target_arch = "x86"),
-    feature(naked_functions)
-)]
+#![cfg_attr(all(linux_raw, asm, target_arch = "x86"), feature(naked_functions))]
 #![cfg_attr(io_lifetimes_use_std, feature(io_safety))]
 #![cfg_attr(not(feature = "std"), no_std)]
 #![cfg_attr(feature = "rustc-dep-of-std", allow(incomplete_features))]
